# coding: utf-8
import datetime

from django.conf import settings
from django.db import models
from django.utils.translation import ugettext_lazy as _
from django.utils.translation import ugettext as ugt

from jmb.core.db.models import DateModel, UserModel, StatusModel, OrderedModel, HTMLFieldTinyMCE
from jmb.i18n.models import Language
from jmb.tag.models import Tag


class CategoryAbstract(DateModel, UserModel, StatusModel, OrderedModel):
    name = models.CharField(
        _('name'),
        max_length=150,
        unique=True,
    )
    slug = models.SlugField(
        _('slug'),
        unique=True,
    )

    class Meta(object):
        abstract = True
        verbose_name = _('Category')
        verbose_name_plural = _('Categories')
        ordering = ("ordering", "name")

    def __unicode__(self):
        return self.name


class SourceAbstract(DateModel, UserModel, OrderedModel, StatusModel):
    name = models.CharField(
        unique=True,
        max_length=100,
        verbose_name=_('name'),
    )
    slug = models.SlugField(
        unique=True,
        max_length=100,
        verbose_name=_('slug'),
    )
    description = models.TextField(
        blank=True, null=True,
        verbose_name=_("note"),
    )

    class Meta:
        abstract = True
        verbose_name = _("Source")
        verbose_name_plural = _("Sources")
        ordering = ('name',)

    def __unicode__(self):
        return self.name


class ContentAbstract(DateModel, UserModel, OrderedModel):
    name = models.CharField(
        _('name'),
        max_length=255,
        #unique=True,
    )
    date_content = models.DateTimeField(
        verbose_name=_("date")
    )
    note = models.TextField(
        _('note'),
        blank=True, null=True,
    )

    @property
    def type_content(self):
        return None

    class Meta(object):
        abstract = True
        verbose_name = _('Content')
        verbose_name_plural = _('Contents')
        ordering = ("ordering", "-date_content", "name")

    def __unicode__(self):
        return self.name


class TranslationContentAbstract(DateModel, UserModel, StatusModel, OrderedModel):
    language = models.ForeignKey(
        Language,
        related_name='%(app_label)s_%(class)s',
        verbose_name=_("Language")
    )
    title = models.CharField(
        _('title'),
        max_length=255,
    )
    slug = models.SlugField(
        _('slug'),
        max_length=255,
        unique=True,
    )
    tags = models.ManyToManyField(
        Tag,
        related_name='%(app_label)s_%(class)s',
        verbose_name=_('tags')
    )
    description = HTMLFieldTinyMCE(
        blank=True, null=True,
        verbose_name=_('description')
    )
    note = models.TextField(
        _('note'),
        blank=True, null=True,
    )

    class Meta(object):
        abstract = True
        verbose_name = _('Content Translation')
        verbose_name_plural = _('Content Translations')
        ordering = ("ordering", "language", "title")
        # unique_together = ('language', 'content',)

    def __unicode__(self):
        return self.title